sequencetools.iterate_sequence_pairwise_wrapped
===============================================

.. autofunction:: abjad.tools.sequencetools.iterate_sequence_pairwise_wrapped.iterate_sequence_pairwise_wrapped
